# Changelog

## [1.4.1](https://github.com/CoreySpohn/lod_unit/compare/v1.4.0...v1.4.1) (2024-03-26)


### Bug Fixes

* **version:** Updating the way version files are created ([#14](https://github.com/CoreySpohn/lod_unit/issues/14)) ([e4b03ee](https://github.com/CoreySpohn/lod_unit/commit/e4b03ee7723105226391d56a89feebfc479c3268))

## [1.4.0](https://github.com/CoreySpohn/lod_unit/compare/v1.3.0...v1.4.0) (2024-03-26)


### Features

* Readthedocs ([#11](https://github.com/CoreySpohn/lod_unit/issues/11)) ([8e8dcbf](https://github.com/CoreySpohn/lod_unit/commit/8e8dcbffc20dba243abb6bb064319588a6a7e704))

## [1.3.0](https://github.com/CoreySpohn/lod_unit/compare/v1.2.0...v1.3.0) (2024-03-26)


### Features

* Adding documentation ([#9](https://github.com/CoreySpohn/lod_unit/issues/9)) ([bd2e188](https://github.com/CoreySpohn/lod_unit/commit/bd2e18888891f3ec2ee848235c110f4b46c99412))

## [1.2.0](https://github.com/CoreySpohn/lod_unit/compare/v1.1.2...v1.2.0) (2024-03-26)


### Features

* Adding doc-style checks with ruff ([2b263e8](https://github.com/CoreySpohn/lod_unit/commit/2b263e8bc782b604cfab4272d086fabe08d1420c))
* Adding pyright type checking ([2b263e8](https://github.com/CoreySpohn/lod_unit/commit/2b263e8bc782b604cfab4272d086fabe08d1420c))

## [1.1.2](https://github.com/CoreySpohn/lod_unit/compare/v1.1.1...v1.1.2) (2024-03-22)


### Bug Fixes

* removing redundant failing part of publish-to-pypi.yml that was replaced with please-release ([b7e3630](https://github.com/CoreySpohn/lod_unit/commit/b7e36304f99271515cafd76533525b366855d2cb))

## [1.1.1](https://github.com/CoreySpohn/lod_unit/compare/v1.1.0...v1.1.1) (2024-03-22)


### Bug Fixes

* migrating to hatch-vcs ([2fa41c6](https://github.com/CoreySpohn/lod_unit/commit/2fa41c6dab133e676806e56b8d7310c2fce9fe29))

## [1.1.0](https://github.com/CoreySpohn/lod_unit/compare/v1.0.4...v1.1.0) (2024-03-22)


### Features

* testing Conventional Commit and please-release ([3822281](https://github.com/CoreySpohn/lod_unit/commit/38222814138e11214c617b743951131761b23bdd))
